@@ -63,34 +63,30 @@
 derive_var_afeye <- function(dataset, dataset_occ, loc_var, lat_var, lat_vals, loc_vals = "EYE") {
   # BEGIN DEPRECATION
   if (!missing(lat_vals)) {
-    deprecate_warn(
-      "1.0.0",
+    deprecate_stop(
+      "1.1.0",
       "derive_var_afeye(lat_vals = )",
       details = "Please ensure your laterality values are from the
       set `c('LEFT', 'RIGHT', 'BILATERAL')`"
     )
-  } else {
-    lat_vals <- c("LEFT", "RIGHT", "BILATERAL")
   }
 
   if (!missing(dataset_occ)) {
-    deprecate_warn(
-      "1.0.0",
+    deprecate_stop(
+      "1.1.0",
       "derive_var_afeye(dataset_occ = )",
       "derive_var_afeye(dataset = )"
     )
-    dataset <- dataset_occ
   }
 
   # END DEPRECATION
 
   seye_vals <- c("LEFT", "RIGHT", "BILATERAL")
+  lat_vals <- c("LEFT", "RIGHT", "BILATERAL")
 
   loc_var <- assert_symbol(enexpr(loc_var))
   lat_var <- assert_symbol(enexpr(lat_var))
 
-  assert_character_vector(loc_vals)
-  assert_character_vector(seye_vals)
   assert_character_vector(lat_vals)
 
   assert_data_frame(dataset, required_vars = expr_c(
